# -*- coding: utf-8 -*-
"""
Anonymize the third formative evaluation round of the Dutch translation. We cannot provide the non-
anonymized data, so you cannot run this code yourself.

Required files:
    - Prolific_Exports/Round_3/prolific_export_dutch_round_3_female_2023_08_25.xlsx
    - Prolific_Exports/Round_3/prolific_export_dutch_round_3_male_nonbinary_2023_08_25.xlsx
    - Qualtrics_Exports/Round_3/Final_ASA_Dutch_Round3_2023_08_25.csv

Output files:
    - Prolific_Exports/Round_3/prolific_export_dutch_round3_anonym.csv
    - Qualtrics_Exports/Round_3/Final_ASA_Dutch_Round_3_anonym.csv

Date: August 2023
Author: Nele Albers
"""

import pandas as pd


def anonymize(df_q, df_p, id_extension):
    """
    Anonymize the Qualtrics and Prolific data.
    Creates a new random ID called "rand_id".

    Parameters
    ----------
    df_q : dataframe
        Qualtrics data.
    df_p : dataframe
        Prolific data.
    id_extension : string
        Extension to add to new random IDs.

    Returns
    -------
    df_q : dataframe
        Anonymized Qualtrics data.
    df_p : dataframe
        Anonymized Prolific data.

    """

    # Only use qualtrics data of people who passed in prolific
    df_q = df_q[df_q["PROL_ID_C"].isin(df_p["Participant id"].to_list())]

    # Remove columns we cannot publish from Qualtrics data
    df_q = df_q.drop(["StartDate", "EndDate", "Status", "Progress", 
                      "Duration (in seconds)", "RecordedDate", "ResponseId", 
                      "DistributionChannel", "UserLanguage",
                      "PIV_E_G_Fluency", "agentName", "SESSION_ID",
                      "STUDY_ID", "Consent2", "PROLIFIC_PID",
                      "TIME_VID_INTRO_First Click", "TIME_VID_INTRO_Last Click",
                      "TIME_VID_INTRO_Page Submit", "TIME_VID_INTRO_Click Count"], 
                     axis = 1)

    # Ceate new random ID
    prolific_ids_sorted = sorted(df_q["PROL_ID_C"].to_list())
    df_q["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_q.iloc[i]["PROL_ID_C"]) + 1) + id_extension for i in range(len(df_q))]
    df_p["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_p.iloc[i]["Participant id"]) + 1) + id_extension for i in range(len(df_p))]

    # Drop original ID columns
    df_q = df_q.drop(["PROL_ID_C"], axis = 1)
    df_p = df_p.drop(["Participant id"], axis = 1)

    return df_q, df_p


if __name__ == "__main__":

    # Load data
    df_q = pd.read_csv("Qualtrics_Exports/Round_3/Final_ASA_Dutch_Round3_2023_08_25.csv")
    df_p_m = pd.read_excel("Prolific_Exports/Round_3/prolific_export_dutch_round_3_male_nonbinary_2023_08_25.xlsx")
    df_p_f = pd.read_excel("Prolific_Exports/Round_3/prolific_export_dutch_round_3_female_2023_08_25.xlsx")

    # Merge male and female Prolific data
    df_p = pd.concat([df_p_m, df_p_f])

    # Anonymize
    df_q, df_p = anonymize(df_q, df_p, "_R3")

    # Save anonymized dataframes
    df_p.to_csv("Prolific_Exports/Round_3/prolific_export_dutch_round3_anonym.csv",
                index=False)
    df_q.to_csv("Qualtrics_Exports/Round_3/Final_ASA_Dutch_Round_3_anonym.csv",
                index=False)
